#!/bin/sh
[ -z "$BASH" ] && { echo "Gmurf configuration requires bash..." 1>&2; exit 1; }

# Constants
DEF_INSTALL_PATH="/opt/Gmurf"
DEF_SND_DEVICE="/dev/dsp"
DEF_USE_OSS="1"
DEF_USE_ESD="1"

# Cleaning

rm -f Constants/Config.h
rm -f Makefile.in

# Path configuration
if [ "$1" = "" ]
then
    INSTALL_PATH=$DEF_INSTALL_PATH
    echo "Where do you wish to install Gmurf: (default: $INSTALL_PATH)"
    read TMP
    if [ "$TMP" != "" ]
	then
	INSTALL_PATH=$TMP
    fi
else
    INSTALL_PATH="$1"
fi

if [ "$2" = "" ]
then
    SND_DEVICE=$DEF_SND_DEVICE
    echo "What file do you want to use as the default sound device if your"
    echo "driver is not the true OSS: (default: $SND_DEVICE)"
    read TMP
    if [ "$TMP" != "" ]
    then
	SND_DEVICE=$TMP
    fi
else
    SND_DEVICE="$2"
fi

if [ "$3" = "" ]
then
    USE_OSS=$DEF_USE_OSS
    echo "Do you want to use the OSS driver or emulation for sound output? "
    echo "(y/n - default: y)"
    read TMP
    case "$TMP" in
	"y")
	    USE_OSS="1"
	    ;;
	"yes")
	    USE_OSS="1"
	    ;;
	"Y")
	    USE_OSS="1"
	    ;;
	"YES")
	    USE_OSS="1"
	    ;;
	"n")
	    USE_OSS="0"
	    ;;
	"no")
	    USE_OSS="0"
	    ;;
	"N")
	    USE_OSS="0"
	    ;;
	"NO")
	    USE_OSS="0"
	    ;;
    esac
else
    USE_OSS="$3"
fi

if [ "$4" = "" ]
then
    USE_ESD=$DEF_USE_ESD
    echo "Do you want to use the esound API for sound output if available?"
    echo "(y/n - default: y)"
    read TMP
    case "$TMP" in
	"y")
	    USE_ESD="1"
	    ;;
	"yes")
	    USE_ESD="1"
	    ;;
	"Y")
	    USE_ESD="1"
	    ;;
	"YES")
	    USE_ESD="1"
	    ;;
	"n")
	    USE_ESD="0"
	    ;;
	"no")
	    USE_ESD="0"
	    ;;
	"N")
	    USE_ESD="0"
	    ;;
	"NO")
	    USE_ESD="0"
	    ;;
    esac
else
    USE_ESD="$4"
fi

echo "PWD = `pwd`" >> Makefile.in
echo "#define DEF_PATH \"$INSTALL_PATH/\"" >> `pwd`/Constants/Config.h
echo "INSTALL_DIR = $INSTALL_PATH/" >> Makefile.in

# Sound device
echo "#define DSP_DEVICE \"$SND_DEVICE\"" >> `pwd`/Constants/Config.h

if [ $USE_OSS = "1" ]
then
    echo "#define OSS_SOUND" >> `pwd`/Constants/Config.h
fi

# OS testing

if grep `uname` scripts/supported_os > /dev/null
then
    echo "OS type: `uname`; that should be OK."
else
    echo "*** WARNING! ***"
    echo "`uname` was not tested yet! Gmurf may not compile well!"
    echo "Here is the list of tested operating systems:"
    cat scripts/supported_os
fi

echo "#define OS_TYPE \"`uname`\"" >> Constants/Config.h
echo "#define __`uname`" >> Constants/Config.h

if [ `uname` = NetBSD ]
then
    echo "OSSEMU_LIBS = -lossaudio" >> Makefile.in
fi

# GTK testing

if [ `gtk-config --version | cut -c 1-3` = "1.2" ]
then
    echo "gtk v1.2.x detected OK."
    echo "GTK_CONFIG = gtk-config" >> Makefile.in
else
    if [ `gtk-config-1.2 --version | cut -c 1-3` = "1.2" ]
    then
	echo "Epita-style gtk v1.2.x detected OK."
	echo "GTK_CONFIG = gtk-config-1.2" >> Makefile.in
    else
	echo "*** WARNING! ***"
	echo "Your version of gtk is `gtk-config --version`. We need gtk v1.2"\
	"or later."

	echo "GTK_CONFIG = gtk-config" >> Makefile.in
    fi
fi

# EsounD testing

if [ $USE_ESD = "1" ]
then
    if [ `esd-config --version | cut -c 1-3` = "0.2" ]
    then
	echo "EsounD v0.2.x detected OK."
	echo "ESD_LIBS = \"`esd-config --libs`\"" >> Makefile.in
	echo "ESD_FLAGS = \"`esd-config --cflags`\"" >> Makefile.in
	echo "#define ESD_SOUND" >> `pwd`/Constants/Config.h
    else
	echo "EsounD v0.2.x was not detected. EsounD provides network hardware sharing."
    fi
fi

# Plugins configuration

cp -f scripts/Filter.conf ./Filter
cp -f scripts/Sound_File_Loader.conf ./Sound_File_Loader
cp -f scripts/Sound_File_Saver.conf ./Sound_File_Saver

for filter in `ls plugins/filters`; do
    echo "1 \"$filter\" \"$INSTALL_PATH/plugins/filters/$filter/$filter\"" >> Filter
done;

echo "\$end_filter" >> Filter

for loader in `ls plugins/loaders`; do
    echo "\"`echo $loader | cut -c 6-`\" \"$INSTALL_PATH/plugins/loaders/$loader/$loader\"    " >> Sound_File_Loader
done;

for saver in `ls plugins/savers`; do
    echo "\"`echo $saver | cut -c 6-`\" \"$INSTALL_PATH/plugins/savers/$saver/$saver\"
    " >> Sound_File_Saver
done;
